@@ -16,10 +16,10 @@ use std::path::PathBuf;
 use super::error::MissingPrefixBufError;
 use super::error::MissingPrefixError;
 use super::error::ParentError;
-use super::imp;
+use super::normalize;
 use super::PathExt;
 
-/// A path that has a [prefix] on Windows.
+/// A borrowed path that has a [prefix] on Windows.
 ///
 /// Note that comparison traits such as [`PartialEq`] will compare paths
 /// literally instead of comparing components. The former is more efficient and
@@ -36,17 +36,14 @@ use super::PathExt;
 /// causes immediate undefined behavior.
 ///
 /// [prefix]: ::std::path::Prefix
-#[derive(Debug, Eq, Hash, PartialEq, PartialOrd)]
+#[derive(Debug, Eq, Hash, Ord, PartialEq, PartialOrd)]
 #[repr(transparent)]
 pub struct BasePath(pub(super) OsStr);
 
 impl BasePath {
     fn from_inner(path: &OsStr) -> &Self {
         // SAFETY: This struct has a layout that makes this operation safe.
-        #[allow(clippy::transmute_ptr_to_ptr)]
-        unsafe {
-            mem::transmute(path)
-        }
+        unsafe { mem::transmute(path) }
     }
 
     /// Creates a new base path.
@@ -86,7 +83,7 @@ impl BasePath {
         match path {
             Cow::Borrowed(path) => Self::try_new(path)
                 .map(Cow::Borrowed)
-                .or_else(|_| imp::to_base(path).map(Cow::Owned)),
+                .or_else(|_| normalize::to_base(path).map(Cow::Owned)),
             Cow::Owned(path) => BasePathBuf::new(path).map(Cow::Owned),
         }
     }
@@ -122,7 +119,7 @@ impl BasePath {
         P: AsRef<Path> + ?Sized,
     {
         let path = path.as_ref();
-        if imp::is_base(path) {
+        if normalize::is_base(path) {
             Ok(Self::from_inner(path.as_os_str()))
         } else {
             Err(MissingPrefixError(()))
@@ -147,14 +144,13 @@ impl BasePath {
     #[inline]
     pub fn canonicalize(&self) -> io::Result<BasePathBuf> {
         self.as_path().canonicalize().map(|base| {
-            debug_assert!(imp::is_base(&base));
+            debug_assert!(normalize::is_base(&base));
             BasePathBuf(base.into_os_string())
         })
     }
 
     /// Equivalent to [`Path::components`].
     #[inline]
-    #[must_use]
     pub fn components(&self) -> Components<'_> {
         self.as_path().components()
     }
@@ -271,6 +267,15 @@ impl BasePath {
         base
     }
 
+    /// Equivalent to [`PathExt::localize_name`].
+    #[cfg(feature = "localization")]
+    #[cfg_attr(normpath_docs_rs, doc(cfg(feature = "localization")))]
+    #[inline]
+    #[must_use]
+    pub fn localize_name(&self) -> Cow<'_, OsStr> {
+        self.as_path().localize_name()
+    }
+
     /// Equivalent to [`Path::metadata`].
     #[inline]
     pub fn metadata(&self) -> io::Result<Metadata> {
@@ -458,11 +463,15 @@ impl ToOwned for BasePath {
 
     #[inline]
     fn to_owned(&self) -> Self::Owned {
-        BasePathBuf(self.0.to_os_string())
+        BasePathBuf(self.0.to_owned())
     }
 }
 
-/// An owned [`BasePath`].
+/// An owned path that has a [prefix] on Windows.
+///
+/// For more information, see [`BasePath`].
+///
+/// [prefix]: ::std::path::Prefix
 #[derive(Clone, Debug, Eq, Hash, Ord, PartialEq, PartialOrd)]
 pub struct BasePathBuf(pub(super) OsString);
 
@@ -491,7 +500,7 @@ impl BasePathBuf {
     where
         P: Into<PathBuf>,
     {
-        Self::try_new(path).or_else(|x| imp::to_base(&x.0))
+        Self::try_new(path).or_else(|x| normalize::to_base(&x.0))
     }
 
     /// Equivalent to [`BasePath::try_new`] but returns an owned path.
@@ -519,7 +528,7 @@ impl BasePathBuf {
         P: Into<PathBuf>,
     {
         let path = path.into();
-        if imp::is_base(&path) {
+        if normalize::is_base(&path) {
             Ok(Self(path.into_os_string()))
         } else {
             Err(MissingPrefixBufError(path))
@@ -622,7 +631,7 @@ impl BasePathBuf {
     where
         P: AsRef<Path>,
     {
-        imp::push(self, path.as_ref());
+        normalize::push(self, path.as_ref());
     }
 }
 
@@ -685,29 +694,45 @@ impl From<BasePathBuf> for PathBuf {
 }
 
 #[cfg(feature = "print_bytes")]
+#[cfg_attr(normpath_docs_rs, doc(cfg(feature = "print_bytes")))]
 mod print_bytes {
-    use print_bytes::Bytes;
+    use print_bytes::ByteStr;
     use print_bytes::ToBytes;
+    #[cfg(windows)]
+    use print_bytes::WideStr;
 
     use super::BasePath;
     use super::BasePathBuf;
 
     impl ToBytes for BasePath {
         #[inline]
-        fn to_bytes(&self) -> Bytes<'_> {
+        fn to_bytes(&self) -> ByteStr<'_> {
             self.0.to_bytes()
         }
+
+        #[cfg(windows)]
+        #[inline]
+        fn to_wide(&self) -> Option<WideStr> {
+            self.0.to_wide()
+        }
     }
 
     impl ToBytes for BasePathBuf {
         #[inline]
-        fn to_bytes(&self) -> Bytes<'_> {
+        fn to_bytes(&self) -> ByteStr<'_> {
             (**self).to_bytes()
         }
+
+        #[cfg(windows)]
+        #[inline]
+        fn to_wide(&self) -> Option<WideStr> {
+            (**self).to_wide()
+        }
     }
 }
 
 #[cfg(feature = "serde")]
+#[cfg_attr(normpath_docs_rs, doc(cfg(feature = "serde")))]
 mod serde {
     use std::ffi::OsString;
 
@@ -749,3 +774,28 @@ mod serde {
         }
     }
 }
+
+#[cfg(feature = "uniquote")]
+#[cfg_attr(normpath_docs_rs, doc(cfg(feature = "uniquote")))]
+mod uniquote {
+    use uniquote::Formatter;
+    use uniquote::Quote;
+    use uniquote::Result;
+
+    use super::BasePath;
+    use super::BasePathBuf;
+
+    impl Quote for BasePath {
+        #[inline]
+        fn escape(&self, f: &mut Formatter<'_>) -> Result {
+            self.0.escape(f)
+        }
+    }
+
+    impl Quote for BasePathBuf {
+        #[inline]
+        fn escape(&self, f: &mut Formatter<'_>) -> Result {
+            (**self).escape(f)
+        }
+    }
+}
